@@ -9,7 +9,13 @@ from tktl.login import logout
 def test_get_deployment_commands(logged_in_context):
     cmd = GetDeployments()
     result = cmd.execute(
-        UUID4("33fb5b8f-e6a2-4dd2-86ef-d257d2c59b85"), None, None, None, None, None
+        UUID4("33fb5b8f-e6a2-4dd2-86ef-d257d2c59b85"),
+        None,
+        None,
+        None,
+        None,
+        None,
+        return_all=False,
     )
     assert len(result) == 2
 
@@ -33,5 +39,11 @@ def test_get_deployment_commands(logged_in_context):
     with pytest.raises(APIClientException):
         logout()
         cmd.execute(
-            UUID4("7c0f6f48-0220-450a-b4d2-bfc731f94cc3"), None, None, None, None, None
+            UUID4("7c0f6f48-0220-450a-b4d2-bfc731f94cc3"),
+            None,
+            None,
+            None,
+            None,
+            None,
+            return_all=True,
         )
