@@ -7,7 +7,7 @@ from tktl.commands.init import init_project
 _logger = logging.getLogger("root")
 
 
-@click.command()
+@click.command(help="Creates project scaffolding")
 @click.option(
     "--name", help="Name of the project", default="tktl-serving", required=True
 )
@@ -15,9 +15,10 @@ _logger = logging.getLogger("root")
     "--path", help="Directory where the new project will be created", required=False
 )
 def init(path: str, name: str) -> None:
-    """Creates a new project with the necessary scaffolding, as well as the supporting
-    files needed. The directory structure of a new project , and the files within it
-    will look like this::
+    """Creates a new project with the necessary scaffolding.
+
+    Creates the supporting files needed. The directory structure of a new
+    project , and the files within it will look like this:
 
         .dockerignore
         .gitattributes
