@@ -1,13 +1,13 @@
 import json
 import os
 from http import HTTPStatus
-from json import JSONDecodeError
 from typing import Optional
 
 import requests
 import tenacity  # type: ignore
 from openapi_schema_pydantic import OpenAPI  # type: ignore
 from requests import ConnectionError, Timeout
+from taktile_types.enums.instance import ServiceType
 
 from tktl.core.clients import Client
 from tktl.core.clients.http_client import API, interpret_response
@@ -18,7 +18,6 @@ from tktl.core.exceptions.exceptions import (
 )
 from tktl.core.loggers import LOG, Logger
 from tktl.core.schemas.repository import _format_http_url
-from tktl.core.t import ServiceT
 
 # codes for which retry-ing is not necessary, and for which
 # precise error information can be retrieved either from
@@ -35,7 +34,7 @@ class RestClient(Client):
     def get_schema(self, *args, **kwargs):
         pass
 
-    TRANSPORT = ServiceT.REST
+    TRANSPORT = ServiceType.REST
 
     def __init__(
         self,
@@ -144,7 +143,11 @@ class RestClient(Client):
                         status_code=response.status_code,
                         detail=json_response["detail"],
                     ) from e
-                except (JSONDecodeError, KeyError) as e:
+                except (ValueError, KeyError) as e:
+                    # Note that we use ValueError instead of JSONDecodeError above on purpose,
+                    # because depending on runtime configuration `requests` might choose to
+                    # use `simplejson` which has a different JSONDecodeError. However both derive
+                    # from ValueError.
                     content = response.text
                     raise APIClientExceptionRetryable(
                         status_code=response.status_code,
