@@ -1,3 +1,4 @@
+from json import JSONDecodeError
 from typing import List, Optional, Tuple
 
 from pydantic import UUID4
@@ -12,6 +13,7 @@ from tktl.core.clients.utils import (
 )
 from tktl.core.config import settings
 from tktl.core.exceptions import TaktileSdkError
+from tktl.core.exceptions.exceptions import APIClientException
 from tktl.core.loggers import LOG, Logger
 from tktl.core.managers.auth import AuthConfigManager
 from tktl.core.schemas.deployment import DeploymentBase
@@ -93,13 +95,13 @@ class DeploymentApiClient(API):
 
     def get_deployments(
         self,
-        repository_id: UUID4 = None,
-        git_hash: str = None,
-        branch_name: str = None,
-        status_name: str = None,
-        repository_name: str = None,
-        repository_owner: str = None,
-        return_all: bool = False,
+        repository_id: Optional[UUID4],
+        git_hash: Optional[str],
+        branch_name: Optional[str],
+        status_name: Optional[str],
+        repository_name: Optional[str],
+        repository_owner: Optional[str],
+        return_all: bool,
     ) -> Optional[List[RepositoryDeployment]]:
 
         repositories = filter_repositories(
@@ -117,6 +119,7 @@ class DeploymentApiClient(API):
                 deployments = repo[0].deployments
         else:
             deployments = flatten([r.deployments for r in repositories])
+
         if return_all:
             filtered_deployments = deployments
         else:
@@ -126,9 +129,15 @@ class DeploymentApiClient(API):
                 branch_name=branch_name,
                 status_name=status_name,
             )
+
+        def get_number_of_endpoints(deployment: RepositoryDeployment):
+            try:
+                return len(get_endpoints_for_deployment(deployment))
+            except (JSONDecodeError, APIClientException):
+                return 0
+
         endpoints_for_deployment = [
-            len(get_endpoints_for_deployment(deployment))
-            for deployment in filtered_deployments
+            get_number_of_endpoints(deployment) for deployment in filtered_deployments
         ]
         for e, d in zip(endpoints_for_deployment, filtered_deployments):
             d.n_endpoints = e
