@@ -15,7 +15,6 @@ class Settings(BaseSettings):
     WEB_URL: str = "https://app.taktile.com"
     TAKTILE_API_URL: str = "https://taktile-api.taktile.com"
     DEPLOYMENT_API_URL: str = "https://deployment-api.taktile.com"
-    LOG_HOST: str = "https://logs.taktile.com"
 
     TKTL_CONFIG_PATH: str = os.path.expanduser("~/.config/tktl")
     CONFIG_FILE_NAME: str = "config.json"
@@ -31,6 +30,9 @@ class Settings(BaseSettings):
     LOCAL_ARROW_ENDPOINT: str = "grpc+tcp://127.0.0.1:5005"
     LOCAL_REST_ENDPOINT: str = "http://127.0.0.1:8080"
     ARROW_BATCH_MB: int = 50
+    PARQUET_BATCH_DEFAULT_ROWS_READ: int = int(1e6)
+
+    FUTURE_ENDPOINTS: bool = False
 
     class Config:
         case_sensitive = True
