@@ -1,9 +1,11 @@
 import os
+import pathlib
 import pkgutil
 import sys
 from typing import Optional
 
 from tktl import __version__
+from tktl.core.config import settings
 from tktl.core.loggers import LOG
 from tktl.core.managers.base import BaseConfigManager
 from tktl.core.managers.constants import TEMPLATE_PROJECT_DIRS, TEMPLATE_PROJECT_FILES
@@ -62,6 +64,8 @@ class ProjectManager(BaseConfigManager):
     @classmethod
     def copy_dist_files(cls) -> None:
         for file in TEMPLATE_PROJECT_FILES:
+            if settings.FUTURE_ENDPOINTS:
+                file = str(pathlib.Path("future", file))
             data = pkgutil.get_data("tktl", file)
             cls._copy_file(file, data)
 
@@ -73,7 +77,8 @@ class ProjectManager(BaseConfigManager):
 
     @classmethod
     def _copy_file(cls, file, data, replace_path=""):
-        file_path = file.replace("template/", replace_path)
+        strip = "template/" if not settings.FUTURE_ENDPOINTS else "future/template/"
+        file_path = file.replace(strip, replace_path)
         try:
             with open(os.path.join(cls.TKTL_DIR, file_path), "w") as f:
                 f.write(data.decode("utf-8").replace("__version__", __version__))
