@@ -2,7 +2,7 @@ from typing import List, Optional, Union
 
 from pydantic import BaseModel
 
-from tktl.core.t import InstanceTypeT, ProjectAssetSourceT, ProjectAssetT, ServiceT
+from tktl.core.t import InstanceTypeT, ProjectAssetSourceT, ProjectAssetT
 
 
 class ProjectContentsBase(BaseModel):
@@ -31,10 +31,20 @@ class ProjectAsset(ProjectContentsBase):
     requires_download: bool
 
 
-class TktlServiceConfigSchema(BaseModel):
+class RestServiceConfigSchema(BaseModel):
+    replicas: int
+    max_replicas: int
+    instance_type: InstanceTypeT
+
+
+class ArrowServiceConfigSchema(BaseModel):
     replicas: int
     instance_type: InstanceTypeT
-    service_type: ServiceT
+
+
+class TktlServiceConfigSchema(BaseModel):
+    rest: RestServiceConfigSchema
+    arrow: ArrowServiceConfigSchema
 
 
 class TktlYamlConfigSchema(BaseModel):
@@ -43,10 +53,14 @@ class TktlYamlConfigSchema(BaseModel):
     deployment_prefix?: master
     service:
 
-      replicas: 2
-      instance_type: gp.small
-      service_type: rest
+      rest:
+        instance_type: gp.small
+        replicas: 1
+        max_replicas: 1
 
+      arrow:
+        instance_type: gp.small
+        replicas: 1
 
     version: version
     """
