@@ -2,7 +2,7 @@ import abc
 from abc import ABC
 from typing import Any, Type, Union
 
-import pyarrow
+import pyarrow  # type: ignore
 from pydantic import BaseModel
 
 
@@ -12,12 +12,12 @@ class ObjectSerializer(abc.ABC):
     def serialize(
         cls, value: Any, output_model: Type[BaseModel] = None
     ) -> Union[pyarrow.Table, BaseModel]:
-        raise NotImplemented
+        raise NotImplementedError
 
     @classmethod
     @abc.abstractmethod
     def deserialize(cls, value: Any) -> Any:
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class CustomDeserializingModelT(ABC, BaseModel):
