@@ -33,6 +33,7 @@ class DeploymentStateFailed(str, ExtendedEnum):
     BUILDING_FAILED = "building_failed"
     DEPLOYING_FAILED = "deploying_failed"
     ROUTING_FAILED = "routing_failed"
+    PROFILING_FAILED = "profiling_failed"
     ERRORED = "errored"
 
 
@@ -44,6 +45,7 @@ class DeploymentStatePending(str, ExtendedEnum):
     BUILDING = "building"
     DEPLOYING = "deploying"
     ROUTING = "routing"
+    PROFILING = "profiling"
 
 
 class DeploymentStatesT(str, ExtendedEnum):
@@ -51,6 +53,7 @@ class DeploymentStatesT(str, ExtendedEnum):
     BUILDING = "building"
     DEPLOYING = "deploying"
     ROUTING = "routing"
+    PROFILING = "profiling"
     RUNNING = "running"
     DELETED = "deleted"
 
@@ -58,6 +61,7 @@ class DeploymentStatesT(str, ExtendedEnum):
     DEPLOYING_FAILED = "deploying_failed"
 
     ROUTING_FAILED = "routing_failed"
+    PROFILING_FAILED = "profiling_failed"
 
     # Error after entering the running state
     ERRORED = "errored"
@@ -81,30 +85,12 @@ class InstanceTypeT(str, ExtendedEnum):
     GP_LARGE = "gp.large"
     GP_XLARGE = "gp.xlarge"
     GP_2XLARGE = "gp.xxlarge"
-
-
-class InstanceSizeT(ExtendedEnum):
-    # also change in taktile-cli: tktl/core/t.py
-    SMALL = "small"
-    MEDIUM = "medium"
-    LARGE = "large"
-    XLARGE = "xlarge"
-    XXLARGE = "xxlarge"
-
-
-class ComputeTypeT(ExtendedEnum):
-    # general purpose
-    GP = "gp"
-
-
-class ServiceT(str, ExtendedEnum):
-    REST = "rest"
-    GRPC = "grpc"
-
-
-class ServiceKindT(str, ExtendedEnum):
-    REST = "rest"
-    ARROW = "arrow"
+    GPU_SMALL = "gpu.small"
+    CPU_SMALL = "cpu.small"
+    CPU_MEDIUM = "cpu.medium"
+    CPU_LARGE = "cpu.large"
+    CPU_XLARGE = "cpu.xlarge"
+    CPU_2XLARGE = "cpu.xxlarge"
 
 
 class EndpointKinds(str, ExtendedEnum):
