@@ -18,8 +18,10 @@ click_completion.init()
 
 @click.group(cls=ClickGroup, **settings.HELP_COLORS_DICT)
 @click.option("-v", "--verbose", count=True, help="Set verbosity level")
-def cli(verbose):
+@click.option("--future", default=False, is_flag=True, help="Use future implementation")
+def cli(verbose, future):
     set_verbosity(verbose)
+    settings.FUTURE_ENDPOINTS = future
 
 
 cli.add_command(get_version)
