@@ -7,7 +7,12 @@ from cached_property import cached_property  # type: ignore
 
 from tktl.core.exceptions import exceptions
 from tktl.core.t import EndpointKinds
-from tktl.core.utils import DelayedLoadingFrame, check_and_get_value
+from tktl.core.utils import (
+    DelayedLoaderX,
+    DelayedLoaderXProfile,
+    DelayedLoaderY,
+    check_and_get_value,
+)
 from tktl.registration.schema import EndpointInputSchema, EndpointOutputSchema
 from tktl.registration.validation import (
     input_pandas_representation,
@@ -24,6 +29,7 @@ class Endpoint(ABC):
     output_schema: EndpointOutputSchema
     explain_input_schema: Optional[EndpointInputSchema]
     delayed_loading: bool
+    profile_columns: Optional[List[str]]
 
     def __init__(
         self,
@@ -95,10 +101,8 @@ class TabularEndpoint(Endpoint):
         if isinstance(X, str) and isinstance(y, str):
             self.delayed_loading = True
 
-            x_value = DelayedLoadingFrame(X, y, profile_columns=profile_columns)
-            y_value = DelayedLoadingFrame(
-                X, y, is_label=True, profile_columns=profile_columns,
-            )
+            x_value = DelayedLoaderX(path=X, label=y)
+            y_value = DelayedLoaderY(path=X, label=y)
 
         else:
             x_value = X
@@ -116,12 +120,8 @@ class TabularEndpoint(Endpoint):
                 self.profile_columns = self.input_schema.names
 
             if self.delayed_loading:
-                explain_input_value = DelayedLoadingFrame(
-                    X,
-                    y,
-                    is_label=False,
-                    profile_columns=self.profile_columns,
-                    load_for_profiling=True,
+                explain_input_value = DelayedLoaderXProfile(
+                    path=X, label=y, columns=self.profile_columns
                 )
             else:
                 explain_input_value = self.input_schema.pandas_representation[
@@ -144,7 +144,7 @@ class TabularEndpoint(Endpoint):
 
             return False
         try:
-            value = check_and_get_value(self.input_schema.value)
+            value = check_and_get_value(self.input_schema.value, first_batch=True)
             predictions = self.func(value)
         except Exception as e:
             raise exceptions.ValidationException(
