@@ -4,9 +4,7 @@ from distutils.version import StrictVersion
 from platform import system
 
 from tktl import __version__
-from tktl.core.loggers import CliLogger
-
-logger = CliLogger()
+from tktl.core.loggers import LOG
 
 
 class PackageNotFoundError(Exception):
@@ -22,8 +20,9 @@ class VersionChecker(object):
         )
         return up_to_date, version_in_repository
 
+    @staticmethod
     def get_version_from_repository(
-        self, module_name, repository_url="http://pypi.python.org/pypi"
+        module_name, repository_url="http://pypi.python.org/pypi"
     ):
         pypi = xmlrpclib.ServerProxy(repository_url)
         versions = pypi.package_releases(module_name)
@@ -69,18 +68,17 @@ class TaktileVersionChecker(object):
                 "taktile-cli", __version__
             )
         except Exception as e:
-            logger.error(e)
+            LOG.error(e)
             return
 
         if not up_to_date:
-            msg = (
-                "Warning: this version of the Taktile CLI ({current_version}) is out of date. "
-                "Some functionality might not be supported until you upgrade. \n\n"
-                "Run `pip install -U tktl` to upgrade\n".format(
-                    current_version=__version__
-                )
-            )
-            logger.warning(msg)
+            msg = f"""
+Warning: this version of the Taktile CLI ({__version__}) is out of date.
+Some functionality might not be supported until you upgrade.
+Latest available version: {version_from_repository}\n
+Run `pip install -U taktile-cli` to upgrade.
+"""
+            LOG.warning(msg)
 
     @staticmethod
     def _should_check_version():
